(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'react-cursor-position', 'react-hover-observer', './ImageZoomLensTop', './ImageZoomLensLeft', './ImageZoomLensRight', './ImageZoomLensBottom', './ImageZoomMagnifier'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('react-cursor-position'), require('react-hover-observer'), require('./ImageZoomLensTop'), require('./ImageZoomLensLeft'), require('./ImageZoomLensRight'), require('./ImageZoomLensBottom'), require('./ImageZoomMagnifier'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.reactCursorPosition, global.reactHoverObserver, global.ImageZoomLensTop, global.ImageZoomLensLeft, global.ImageZoomLensRight, global.ImageZoomLensBottom, global.ImageZoomMagnifier);
        global.ImageZoom = mod.exports;
    }
})(this, function (exports, _react, _reactCursorPosition, _reactHoverObserver, _ImageZoomLensTop, _ImageZoomLensLeft, _ImageZoomLensRight, _ImageZoomLensBottom, _ImageZoomMagnifier) {
    'use strict';

    Object.defineProperty(exports, "__esModule", {
        value: true
    });

    var _react2 = _interopRequireDefault(_react);

    var _reactCursorPosition2 = _interopRequireDefault(_reactCursorPosition);

    var _reactHoverObserver2 = _interopRequireDefault(_reactHoverObserver);

    var _ImageZoomLensTop2 = _interopRequireDefault(_ImageZoomLensTop);

    var _ImageZoomLensLeft2 = _interopRequireDefault(_ImageZoomLensLeft);

    var _ImageZoomLensRight2 = _interopRequireDefault(_ImageZoomLensRight);

    var _ImageZoomLensBottom2 = _interopRequireDefault(_ImageZoomLensBottom);

    var _ImageZoomMagnifier2 = _interopRequireDefault(_ImageZoomMagnifier);

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    var ImageZoom = function ImageZoom(_ref) {
        var className = _ref.className;
        var fadeDurationInMs = _ref.fadeDurationInMs;
        var hoverDelayInMs = _ref.hoverDelayInMs;
        var hoverOffDelayInMs = _ref.hoverOffDelayInMs;
        var largeImage = _ref.largeImage;
        var smallImage = _ref.smallImage;
        var style = _ref.style;


        var cursorOffset = {
            x: Math.round(smallImage.width / largeImage.width * smallImage.width / 2),
            y: Math.round(smallImage.height / largeImage.height * smallImage.height / 2)
        };

        return _react2.default.createElement(
            _reactCursorPosition2.default,
            {
                className: className,
                style: Object.assign({
                    width: smallImage.width + 'px',
                    height: smallImage.height + 'px',
                    cursor: 'crosshair',
                    position: 'relative'
                }, style)
            },
            _react2.default.createElement(
                _reactHoverObserver2.default,
                {
                    hoverDelayInMs: hoverDelayInMs,
                    hoverOffDelayInMs: hoverOffDelayInMs,
                    onMouseEnter: function onMouseEnter(_ref2) {
                        var setIsHovering = _ref2.setIsHovering;
                        return setIsHovering();
                    },
                    onMouseLeave: function onMouseLeave(_ref3) {
                        var unsetIsHovering = _ref3.unsetIsHovering;
                        return unsetIsHovering();
                    },
                    onMouseOver: function onMouseOver(_ref4) {
                        var e = _ref4.e;
                        var unsetIsHovering = _ref4.unsetIsHovering;

                        if (e.target.getAttribute('data-hover') === 'false') {
                            unsetIsHovering();
                        }
                    }
                },
                _react2.default.createElement('img', {
                    src: smallImage.src,
                    alt: smallImage.alt
                }),
                _react2.default.createElement(_ImageZoomLensTop2.default, {
                    fadeDurationInMs: fadeDurationInMs,
                    smallImage: smallImage,
                    cursorOffset: cursorOffset
                }),
                _react2.default.createElement(_ImageZoomLensLeft2.default, {
                    fadeDurationInMs: fadeDurationInMs,
                    smallImage: smallImage,
                    cursorOffset: cursorOffset
                }),
                _react2.default.createElement(_ImageZoomLensRight2.default, {
                    fadeDurationInMs: fadeDurationInMs,
                    smallImage: smallImage,
                    cursorOffset: cursorOffset
                }),
                _react2.default.createElement(_ImageZoomLensBottom2.default, {
                    fadeDurationInMs: fadeDurationInMs,
                    smallImage: smallImage,
                    cursorOffset: cursorOffset
                }),
                _react2.default.createElement(_ImageZoomMagnifier2.default, {
                    fadeDurationInMs: fadeDurationInMs,
                    largeImage: largeImage,
                    smallImage: smallImage,
                    cursorOffset: cursorOffset
                })
            )
        );
    };

    var Image = _react.PropTypes.shape({
        alt: _react.PropTypes.string,
        src: _react.PropTypes.string.isRequired,
        width: _react.PropTypes.number.isRequired,
        height: _react.PropTypes.number.isRequired
    });

    ImageZoom.propTypes = {
        fadeDurationInMs: _react.PropTypes.number,
        className: _react.PropTypes.string,
        hoverDelayInMs: _react.PropTypes.number,
        hoverOffDelayInMs: _react.PropTypes.number,
        largeImage: Image,
        smallImage: Image,
        style: _react.PropTypes.object
    };

    ImageZoom.defaultProps = {
        fadeDurationInMs: 300,
        hoverDelayInMs: 250,
        hoverOffDelayInMs: 150
    };

    exports.default = ImageZoom;
});