(function (global, factory) {
    if (typeof define === "function" && define.amd) {
        define(['exports', 'react', 'lodash.clamp'], factory);
    } else if (typeof exports !== "undefined") {
        factory(exports, require('react'), require('lodash.clamp'));
    } else {
        var mod = {
            exports: {}
        };
        factory(mod.exports, global.react, global.lodash);
        global.ImageZoomMagnifier = mod.exports;
    }
})(this, function (exports, _react, _lodash) {
    'use strict';

    Object.defineProperty(exports, "__esModule", {
        value: true
    });

    var _react2 = _interopRequireDefault(_react);

    var _lodash2 = _interopRequireDefault(_lodash);

    function _interopRequireDefault(obj) {
        return obj && obj.__esModule ? obj : {
            default: obj
        };
    }

    var _extends = Object.assign || function (target) {
        for (var i = 1; i < arguments.length; i++) {
            var source = arguments[i];

            for (var key in source) {
                if (Object.prototype.hasOwnProperty.call(source, key)) {
                    target[key] = source[key];
                }
            }
        }

        return target;
    };

    exports.default = _react2.default.createClass({

        displayName: 'ImageZoomMagnifier',

        getInitialState: function getInitialState() {
            return {
                isTransitionEntering: false,
                isTransitionActive: false,
                isTransitionLeaving: false,
                isTransitionDone: false
            };
        },
        getDefaultPRops: function getDefaultPRops() {
            return {
                fadeDurationInMs: 0
            };
        },
        componentWillReceiveProps: function componentWillReceiveProps(nextProps) {
            var _this = this;

            var isHovering = nextProps.isHovering;


            if (isHovering) {
                this.setState({
                    isTransitionEntering: true
                });

                setTimeout(function () {
                    _this.setState({
                        isTransitionEntering: false,
                        isTransitionActive: true
                    });
                }, 0);
            } else {
                this.setState({
                    isTransitionActive: false,
                    isTransitionLeaving: true
                });

                setTimeout(function () {
                    _this.setState({
                        isTransitionLeaving: false,
                        isTransitionDone: true
                    });
                }, this.props.fadeDurationInMs);
            }
        },
        render: function render() {
            var _props = this.props;
            var className = _props.className;
            var cursorOffset = _props.cursorOffset;
            var cursorPosition = _props.cursorPosition;
            var fadeDurationInMs = _props.fadeDurationInMs;
            var isHovering = _props.isHovering;
            var largeImage = _props.largeImage;
            var smallImage = _props.smallImage;
            var _state = this.state;
            var isTransitionEntering = _state.isTransitionEntering;
            var isTransitionActive = _state.isTransitionActive;
            var isTransitionLeaving = _state.isTransitionLeaving;


            var offsetRatio = {
                x: largeImage.width / smallImage.width,
                y: largeImage.height / smallImage.height
            };

            var differentiatedImageCoordinates = {
                x: Math.round((cursorPosition.x - cursorOffset.x) * offsetRatio.x) * -1,
                y: Math.round((cursorPosition.y - cursorOffset.y) * offsetRatio.y) * -1
            };

            var minCoordinates = {
                x: (largeImage.width - smallImage.width) * -1,
                y: (largeImage.height - smallImage.height) * -1
            };

            var maxCoordinate = 0;

            var imageCoordinates = {
                x: (0, _lodash2.default)(differentiatedImageCoordinates.x, minCoordinates.x, maxCoordinate),
                y: (0, _lodash2.default)(differentiatedImageCoordinates.y, minCoordinates.y, maxCoordinate)
            };

            var translate = 'translate(' + imageCoordinates.x + 'px, ' + imageCoordinates.y + 'px)';

            var isVisible = void 0;
            if (isTransitionEntering || isTransitionActive || isTransitionLeaving) {
                isVisible = true;
            } else {
                isVisible = false;
            }

            var component = _react2.default.createElement(
                'div',
                {
                    className: className,
                    key: 'zoom',
                    style: {
                        width: smallImage.width,
                        height: smallImage.height,
                        marginLeft: '10px',
                        position: 'absolute',
                        left: '100%',
                        top: '0px',
                        border: '1px solid #d6d6d6',
                        overflow: 'hidden',
                        opacity: this.state.isTransitionActive ? 1 : 0,
                        transition: 'opacity ' + fadeDurationInMs + 'ms ease-in'
                    }
                },
                _react2.default.createElement('img', _extends({ 'data-hover': 'false' }, {
                    src: largeImage.src,
                    style: {
                        width: largeImage.width,
                        height: largeImage.height,
                        transform: translate,
                        WebkitTransform: translate,
                        msTransform: translate
                    }
                }))
            );

            return isVisible ? component : null;
        }
    });
});